mysql.constants

Package mysql :: Package constants |
[hide private]
[frames] | no frames]

# Package constants

source code

Subpackage of constants used in the MySQL library.

All submodules are imported here, so there is no need to import each individual one.

Submodules | [hide private]
mysql.constants.client_flags: Flags used for connecting to the server. mysql.constants.field_flags: Flags used in the `flags` attribute of the mysql.result.Field object. mysql.constants.field_types: Identifiers of different field types.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.3 $'`

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.3 $'